@@ -22,10 +22,10 @@ class Ebus:
     This instance connects to an EBUSD instance and allows to read, write or monitor.
     """
 
-    def __init__(self, host, port, timeout=10, scanwaitinterval=5, scanwaits=5, msgdefs=None):
+    def __init__(self, host, port, timeout=10, scaninterval=10, scans=3, msgdefs=None):
         self.connection = Connection(host=host, port=port, autoconnect=True, timeout=timeout)
-        self.scanwaitinterval = scanwaitinterval
-        self.scanwaits = scanwaits
+        self.scaninterval = scaninterval
+        self.scans = scans
         self.msgdefcodes = []
         self.msgdecoder = MsgDecoder(msgdefs or MsgDefs())
         _LOGGER.info(f"{self}")
@@ -36,8 +36,8 @@ class Ebus:
             args=(self.connection.host, self.connection.port),
             kwargs=(
                 ("timeout", self.timeout, 10),
-                ("scanwaitinterval", self.scanwaitinterval, 5),
-                ("scanwaits", self.scanwaits, 5),
+                ("scaninterval", self.scaninterval, 10),
+                ("scans", self.scans, 3),
             ),
         )
 
@@ -66,9 +66,7 @@ class Ebus:
         self.msgdecoder.msgdefs = msgdefs
 
     def __copy__(self):
-        return Ebus(
-            self.host, self.port, timeout=self.timeout, scanwaitinterval=self.scanwaitinterval, msgdefs=self.msgdefs
-        )
+        return Ebus(self.host, self.port, timeout=self.timeout, scaninterval=self.scaninterval, msgdefs=self.msgdefs)
 
     async def wait_scancompleted(self):
         """Wait until scan is completed."""
@@ -76,8 +74,8 @@ class Ebus:
         while True:
             cnt = sum([1 async for line in self._request(_CMD_FINDMSGDEFS)])
             cnts.append(cnt)
-            if len(cnts) < 4 or all(cnt == cnts[0] for cnt in cnts[1:]):
-                await asyncio.sleep(self.scanwaitinterval)
+            if len(cnts) < self.scans or not all(cnt == cnts[-1] for cnt in cnts[-self.scans : -1]):
+                await asyncio.sleep(self.scaninterval)
             else:
                 break
 
